@@ -1,7 +1,7 @@
 #!/usr/local/bin/perl
 
-#isMember.pl 
-#pass the common name of a group entry (assuming groupOfUniqueNames objectclass) and 
+#isMember.pl
+#pass the common name of a group entry (assuming groupOfUniqueNames objectclass) and
 #a uid, the script will tell you if the uid is a member of the group or not.
 
 $version = 3.0_01;
@@ -52,7 +52,7 @@ my $isMember = 0; # by default you are not a member
 my $ldap = new Net::LDAP ($opt_h, port=> $opt_p);
 
 #will bind as specific user if specified else will be binded anonymously
-$ldap->bind($opt_D, password=> $opt_p) || die "failed to bind as $opt_D"; 
+$ldap->bind($opt_D, password=> $opt_p) || die "failed to bind as $opt_D";
 
 
 #get user DN first
@@ -87,7 +87,7 @@ eval
 
    &getIsMember($groupDN,$userDN);
 
-}; 
+};
 
 
 die $mesg->error if $mesg->code;
@@ -170,9 +170,9 @@ sub getIsMember
 
         #if we find an entry it returns true
 	#else keep searching
-	
+
         eval
-	{ 
+	{
           my $entry = $mesg->pop_entry();
 	  print "ldapurl",$entry->dn,"\n" if $DEBUG;
 
@@ -185,7 +185,7 @@ sub getIsMember
 
 
       my $membervalues = $entry->get_value("uniquemember", asref => 1);
-    
+
      foreach my $val (@{$membervalues})
      {
        my $return= &getIsMember($val,$userDN);
@@ -193,13 +193,13 @@ sub getIsMember
        #stop as soon as we have a winner
        last if $isMember;
      }
-     
+
 
      die $mesg->error if $mesg->code;
 
 
      #if make it this far then you must be a member
-  
+
    };
 
    return $0;
@@ -304,7 +304,7 @@ and may not be able to be released, but since I work for a university I
 don't think there will be a problem):
 
 1) script to add/remove members to a group
-2) script to send mail to a list as long as the orignal email address is
+2) script to send mail to a list as long as the original email address is
 from the owner of the group
 3) a web LDAP management system. I've written a bare bones one in
 Netscape's PerLDAP API, but I'd like to write something closer to
